@@ -22,8 +22,8 @@ using boost::unit_test::test_case;
 using namespace zypp;
 
 void testUrlAuthority( const Url & url_r,
-		       const std::string & host_r, const std::string & port_r = std::string(),
-		       const std::string & user_r = std::string(), const std::string & pass_r = std::string() )
+                       const std::string & host_r, const std::string & port_r = std::string(),
+                       const std::string & user_r = std::string(), const std::string & pass_r = std::string() )
 {
   BOOST_CHECK_EQUAL( url_r.getUsername(),	user_r );
   BOOST_CHECK_EQUAL( url_r.getPassword(),	pass_r );
@@ -90,13 +90,15 @@ BOOST_AUTO_TEST_CASE(test_url1)
 
     // asString shouldn't print the password, asCompleteString should.
     // further, the "//" at the begin of the path should be keept.
-    str = "http://user:pass@localhost//srv/ftp";
-    one = "http://user@localhost//srv/ftp";
+    str = "http://user:pass@localhost//srv/ftp?proxypass=@PROXYPASS@&proxy=proxy.my&proxyuser=@PROXYUSER@&Xproxypass=NOTTHIS&proxypass=@PROXYPASS@&proxypass=@PROXYPASS@";
+    one = "http://user@localhost//srv/ftp?proxy=proxy.my&proxyuser=@PROXYUSER@&Xproxypass=NOTTHIS";
     two = str;
     url = str;
 
     BOOST_CHECK_EQUAL( one, url.asString() );
     BOOST_CHECK_EQUAL( two, url.asCompleteString() );
+    // hidden proxypass in the query is available when explicitly asked for
+    BOOST_CHECK_EQUAL( url.getQueryParam( "proxypass" ), "@PROXYPASS@" );
 
     // absolute path defaults to 'file://'
     str = "/some/local/path";
@@ -195,25 +197,26 @@ BOOST_AUTO_TEST_CASE(test_url3)
   BOOST_CHECK_EQUAL( url.asString(),
   "http://localhost/path/to?hoho=ha%20ha#frag");
 
-  // will be encoded as "foo%3Dbar%26key=foo%26bar%3Dvalue"
+  // will be encoded as "foo%3Dbar%26key=foo%26bar=value"
+  // bsc#1234304: `=` must be encoded in key but is a safe char in value
   key = "foo=bar&key";
   val = "foo&bar=value";
   url.setQueryParam(key, val);
   BOOST_CHECK_EQUAL( url.asString(),
-  "http://localhost/path/to?foo%3Dbar%26key=foo%26bar%3Dvalue&hoho=ha%20ha#frag");
+  "http://localhost/path/to?foo%3Dbar%26key=foo%26bar=value&hoho=ha%20ha#frag");
 
   // will be encoded as "foo%25bar=is%25de%25ad"
   key = "foo%bar";
   val = "is%de%ad";
   url.setQueryParam(key, val);
   BOOST_CHECK_EQUAL( url.asString(),
-  "http://localhost/path/to?foo%25bar=is%25de%25ad&foo%3Dbar%26key=foo%26bar%3Dvalue&hoho=ha%20ha#frag");
+  "http://localhost/path/to?foo%25bar=is%25de%25ad&foo%3Dbar%26key=foo%26bar=value&hoho=ha%20ha#frag");
 
   // get encoded query parameters and compare with results:
   zypp::url::ParamVec params( url.getQueryStringVec());
   const char * const  result[] = {
     "foo%25bar=is%25de%25ad",
-    "foo%3Dbar%26key=foo%26bar%3Dvalue",
+    "foo%3Dbar%26key=foo%26bar=value",
     "hoho=ha%20ha"
   };
   BOOST_CHECK( params.size() == (sizeof(result)/sizeof(result[0])));
@@ -285,7 +288,7 @@ BOOST_AUTO_TEST_CASE( test_url5)
 BOOST_AUTO_TEST_CASE(plugin_scriptpath)
 {
   // plugin script path must not be rewritten
-  for ( const std::string & t : { "script", "script/", "/script", "/script/", "./script", "./script/" } )
+  for ( const std::string t : { "script", "script/", "/script", "/script/", "./script", "./script/" } )
   {
     BOOST_CHECK_EQUAL( Url("plugin:"+t).getPathName(),	t );
   }
@@ -313,4 +316,30 @@ BOOST_AUTO_TEST_CASE(plugin_querystring_args)
   BOOST_CHECK_EQUAL( pm["o"], "" );
 }
 
+BOOST_AUTO_TEST_CASE(bsc1234304)
+{
+  // Removing or adding queryparams should not alter the encoding of other queryparams.
+  // Old code decoded and re-encoded all params. "__token__=exp=%3D%26" was changed to
+  // "__token__=exp==%26" by this. That's not wrong, but we'd like to preserve the original
+  // params if possible.
+  Url u { "https://dl.suse.com/?__token__=exp=%3D%261862049599~acl=/SUSE/*~hmac=968c8dc9&t%3Dt" };
+  BOOST_CHECK_EQUAL( u.getQueryString(), "__token__=exp=%3D%261862049599~acl=/SUSE/*~hmac=968c8dc9&t%3Dt" );
+  u.delQueryParam("t=t");
+  BOOST_CHECK_EQUAL( u.getQueryString(), "__token__=exp=%3D%261862049599~acl=/SUSE/*~hmac=968c8dc9" );
+  u.setQueryParam("t=t", "a" );
+  BOOST_CHECK_EQUAL( u.getQueryString(), "__token__=exp=%3D%261862049599~acl=/SUSE/*~hmac=968c8dc9&t%3Dt=a" );
+  u.setQueryParam("t=t", "b" );
+  BOOST_CHECK_EQUAL( u.getQueryString(), "__token__=exp=%3D%261862049599~acl=/SUSE/*~hmac=968c8dc9&t%3Dt=b" );
+
+  u.setQueryParam("local", "b" );
+  BOOST_CHECK_EQUAL( u.getQueryString(), "__token__=exp=%3D%261862049599~acl=/SUSE/*~hmac=968c8dc9&local=b&t%3Dt=b" );
+  u.delQueryParams( { "t=t", "local" } );
+  BOOST_CHECK_EQUAL( u.getQueryString(), "__token__=exp=%3D%261862049599~acl=/SUSE/*~hmac=968c8dc9" );
+
+  // queryparams without value should not have a trailing "="
+  u.setQueryParam("empty", "" );
+  BOOST_CHECK_EQUAL( u.getQueryString(), "__token__=exp=%3D%261862049599~acl=/SUSE/*~hmac=968c8dc9&empty" );
+
+}
+
 // vim: set ts=2 sts=2 sw=2 ai et:
